@@ -80,7 +80,7 @@ void SetMessageVariables(const FieldDescriptor* descriptor,
                          int builderBitIndex,
                          const FieldGeneratorInfo* info,
                          Context* context,
-                         map<string, string>* variables) {
+                         std::map<string, string>* variables) {
   SetCommonFieldVariables(descriptor, info, variables);
 
   ClassNameResolver* name_resolver = context->GetNameResolver();
@@ -142,12 +142,12 @@ void SetMessageVariables(const FieldDescriptor* descriptor,
 ImmutableMapFieldLiteGenerator::
 ImmutableMapFieldLiteGenerator(const FieldDescriptor* descriptor,
                                        int messageBitIndex,
-                                       int builderBitIndex,
                                        Context* context)
-  : descriptor_(descriptor), name_resolver_(context->GetNameResolver())  {
-  SetMessageVariables(descriptor, messageBitIndex, builderBitIndex,
-                      context->GetFieldGeneratorInfo(descriptor),
-                      context, &variables_);
+  : descriptor_(descriptor), context_(context),
+    name_resolver_(context->GetNameResolver()){
+  SetMessageVariables(descriptor, messageBitIndex, 0,
+                      context->GetFieldGeneratorInfo(descriptor), context,
+                      &variables_);
 }
 
 ImmutableMapFieldLiteGenerator::
@@ -157,21 +157,19 @@ int ImmutableMapFieldLiteGenerator::GetNumBitsForMessage() const {
   return 0;
 }
 
-int ImmutableMapFieldLiteGenerator::GetNumBitsForBuilder() const {
-  return 0;
-}
-
 void ImmutableMapFieldLiteGenerator::
 GenerateInterfaceMembers(io::Printer* printer) const {
   WriteFieldDocComment(printer, descriptor_);
   printer->Print(
       variables_,
-      "$deprecation$int get$capitalized_name$Count();\n");
+      "$deprecation$int ${$get$capitalized_name$Count$}$();\n");
+  printer->Annotate("{", "}", descriptor_);
   WriteFieldDocComment(printer, descriptor_);
   printer->Print(
       variables_,
-      "$deprecation$boolean contains$capitalized_name$(\n"
+      "$deprecation$boolean ${$contains$capitalized_name$$}$(\n"
       "    $key_type$ key);\n");
+  printer->Annotate("{", "}", descriptor_);
   if (GetJavaType(ValueField(descriptor_)) == JAVATYPE_ENUM) {
     printer->Print(
         variables_,
@@ -180,23 +178,27 @@ GenerateInterfaceMembers(io::Printer* printer) const {
         " */\n"
         "@java.lang.Deprecated\n"
         "java.util.Map<$boxed_key_type$, $value_enum_type$>\n"
-        "get$capitalized_name$();\n");
+        "${$get$capitalized_name$$}$();\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
         "$deprecation$java.util.Map<$boxed_key_type$, $value_enum_type$>\n"
-        "get$capitalized_name$Map();\n");
+        "${$get$capitalized_name$Map$}$();\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
-        "$deprecation$$value_enum_type$ get$capitalized_name$OrDefault(\n"
+        "$deprecation$$value_enum_type$ ${$get$capitalized_name$OrDefault$}$(\n"
         "    $key_type$ key,\n"
         "    $value_enum_type$ defaultValue);\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
-        "$deprecation$$value_enum_type$ get$capitalized_name$OrThrow(\n"
+        "$deprecation$$value_enum_type$ ${$get$capitalized_name$OrThrow$}$(\n"
         "    $key_type$ key);\n");
+    printer->Annotate("{", "}", descriptor_);
     if (SupportUnknownEnumValue(descriptor_->file())) {
       printer->Print(
           variables_,
@@ -205,25 +207,29 @@ GenerateInterfaceMembers(io::Printer* printer) const {
           " */\n"
           "@java.lang.Deprecated\n"
           "java.util.Map<$type_parameters$>\n"
-          "get$capitalized_name$Value();\n");
+          "${$get$capitalized_name$Value$}$();\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
           "$deprecation$java.util.Map<$type_parameters$>\n"
-          "get$capitalized_name$ValueMap();\n");
+          "${$get$capitalized_name$ValueMap$}$();\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
           "$deprecation$\n"
-          "$value_type$ get$capitalized_name$ValueOrDefault(\n"
+          "$value_type$ ${$get$capitalized_name$ValueOrDefault$}$(\n"
           "    $key_type$ key,\n"
           "    $value_type$ defaultValue);\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
           "$deprecation$\n"
-          "$value_type$ get$capitalized_name$ValueOrThrow(\n"
+          "$value_type$ ${$get$capitalized_name$ValueOrThrow$}$(\n"
           "    $key_type$ key);\n");
+      printer->Annotate("{", "}", descriptor_);
     }
   } else {
     printer->Print(
@@ -233,25 +239,29 @@ GenerateInterfaceMembers(io::Printer* printer) const {
         " */\n"
         "@java.lang.Deprecated\n"
         "java.util.Map<$type_parameters$>\n"
-        "get$capitalized_name$();\n");
+        "${$get$capitalized_name$$}$();\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
         "$deprecation$java.util.Map<$type_parameters$>\n"
-        "get$capitalized_name$Map();\n");
+        "${$get$capitalized_name$Map$}$();\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
         "$deprecation$\n"
-        "$value_type$ get$capitalized_name$OrDefault(\n"
+        "$value_type$ ${$get$capitalized_name$OrDefault$}$(\n"
         "    $key_type$ key,\n"
         "    $value_type$ defaultValue);\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
         "$deprecation$\n"
-        "$value_type$ get$capitalized_name$OrThrow(\n"
+        "$value_type$ ${$get$capitalized_name$OrThrow$}$(\n"
         "    $key_type$ key);\n");
+    printer->Annotate("{", "}", descriptor_);
   }
 }
 
@@ -287,19 +297,23 @@ GenerateMembers(io::Printer* printer) const {
       "}\n");
   printer->Print(
       variables_,
+      "@java.lang.Override\n"
       "$deprecation$\n"
-      "public int get$capitalized_name$Count() {\n"
+      "public int ${$get$capitalized_name$Count$}$() {\n"
       "  return internalGet$capitalized_name$().size();\n"
       "}\n");
+  printer->Annotate("{", "}", descriptor_);
   WriteFieldDocComment(printer, descriptor_);
   printer->Print(
       variables_,
+      "@java.lang.Override\n"
       "$deprecation$\n"
-      "public boolean contains$capitalized_name$(\n"
+      "public boolean ${$contains$capitalized_name$$}$(\n"
       "    $key_type$ key) {\n"
       "  $key_null_check$\n"
       "  return internalGet$capitalized_name$().containsKey(key);\n"
       "}\n");
+  printer->Annotate("{", "}", descriptor_);
   if (GetJavaType(ValueField(descriptor_)) == JAVATYPE_ENUM) {
     printer->Print(
         variables_,
@@ -316,26 +330,30 @@ GenerateMembers(io::Printer* printer) const {
         " */\n"
         "@java.lang.Deprecated\n"
         "public java.util.Map<$boxed_key_type$, $value_enum_type$>\n"
-        "get$capitalized_name$() {\n"
+        "${$get$capitalized_name$$}$() {\n"
         "  return get$capitalized_name$Map();\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
         "public java.util.Map<$boxed_key_type$, $value_enum_type$>\n"
-        "get$capitalized_name$Map() {\n"
+        "${$get$capitalized_name$Map$}$() {\n"
         "  return java.util.Collections.unmodifiableMap(\n"
         "      new com.google.protobuf.Internal.MapAdapter<\n"
         "        $boxed_key_type$, $value_enum_type$, java.lang.Integer>(\n"
         "            internalGet$capitalized_name$(),\n"
         "            $name$ValueConverter));\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_enum_type$ get$capitalized_name$OrDefault(\n"
+        "public $value_enum_type$ ${$get$capitalized_name$OrDefault$}$(\n"
         "    $key_type$ key,\n"
         "    $value_enum_type$ defaultValue) {\n"
         "  $key_null_check$\n"
@@ -345,11 +363,13 @@ GenerateMembers(io::Printer* printer) const {
         "         ? $name$ValueConverter.doForward(map.get(key))\n"
         "         : defaultValue;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_enum_type$ get$capitalized_name$OrThrow(\n"
+        "public $value_enum_type$ ${$get$capitalized_name$OrThrow$}$(\n"
         "    $key_type$ key) {\n"
         "  $key_null_check$\n"
         "  java.util.Map<$boxed_key_type$, $boxed_value_type$> map =\n"
@@ -359,31 +379,37 @@ GenerateMembers(io::Printer* printer) const {
         "  }\n"
         "  return $name$ValueConverter.doForward(map.get(key));\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     if (SupportUnknownEnumValue(descriptor_->file())) {
       printer->Print(
           variables_,
           "/**\n"
           " * Use {@link #get$capitalized_name$ValueMap()} instead.\n"
           " */\n"
+          "@java.lang.Override\n"
           "@java.lang.Deprecated\n"
           "public java.util.Map<$boxed_key_type$, $boxed_value_type$>\n"
-          "get$capitalized_name$Value() {\n"
+          "${$get$capitalized_name$Value$}$() {\n"
           "  return get$capitalized_name$ValueMap();\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
+          "@java.lang.Override\n"
           "$deprecation$\n"
           "public java.util.Map<$boxed_key_type$, $boxed_value_type$>\n"
-          "get$capitalized_name$ValueMap() {\n"
+          "${$get$capitalized_name$ValueMap$}$() {\n"
           "  return java.util.Collections.unmodifiableMap(\n"
           "      internalGet$capitalized_name$());\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
+          "@java.lang.Override\n"
           "$deprecation$\n"
-          "public $value_type$ get$capitalized_name$ValueOrDefault(\n"
+          "public $value_type$ ${$get$capitalized_name$ValueOrDefault$}$(\n"
           "    $key_type$ key,\n"
           "    $value_type$ defaultValue) {\n"
           "  $key_null_check$\n"
@@ -391,11 +417,13 @@ GenerateMembers(io::Printer* printer) const {
           "      internalGet$capitalized_name$();\n"
           "  return map.containsKey(key) ? map.get(key) : defaultValue;\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
+          "@java.lang.Override\n"
           "$deprecation$\n"
-          "public $value_type$ get$capitalized_name$ValueOrThrow(\n"
+          "public $value_type$ ${$get$capitalized_name$ValueOrThrow$}$(\n"
           "    $key_type$ key) {\n"
           "  $key_null_check$\n"
           "  java.util.Map<$boxed_key_type$, $boxed_value_type$> map =\n"
@@ -405,6 +433,7 @@ GenerateMembers(io::Printer* printer) const {
           "  }\n"
           "  return map.get(key);\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
     }
   } else {
     printer->Print(
@@ -412,23 +441,30 @@ GenerateMembers(io::Printer* printer) const {
         "/**\n"
         " * Use {@link #get$capitalized_name$Map()} instead.\n"
         " */\n"
+        "@java.lang.Override\n"
         "@java.lang.Deprecated\n"
-        "public java.util.Map<$type_parameters$> get$capitalized_name$() {\n"
+        "public java.util.Map<$type_parameters$> "
+        "${$get$capitalized_name$$}$() {\n"
         "  return get$capitalized_name$Map();\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public java.util.Map<$type_parameters$> get$capitalized_name$Map() {\n"
+        "public java.util.Map<$type_parameters$> "
+        "${$get$capitalized_name$Map$}$() {\n"
         "  return java.util.Collections.unmodifiableMap(\n"
         "      internalGet$capitalized_name$());\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_type$ get$capitalized_name$OrDefault(\n"
+        "public $value_type$ ${$get$capitalized_name$OrDefault$}$(\n"
         "    $key_type$ key,\n"
         "    $value_type$ defaultValue) {\n"
         "  $key_null_check$\n"
@@ -436,11 +472,13 @@ GenerateMembers(io::Printer* printer) const {
         "      internalGet$capitalized_name$();\n"
         "  return map.containsKey(key) ? map.get(key) : defaultValue;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_type$ get$capitalized_name$OrThrow(\n"
+        "public $value_type$ ${$get$capitalized_name$OrThrow$}$(\n"
         "    $key_type$ key) {\n"
         "  $key_null_check$\n"
         "  java.util.Map<$type_parameters$> map =\n"
@@ -450,6 +488,7 @@ GenerateMembers(io::Printer* printer) const {
         "  }\n"
         "  return map.get(key);\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
   }
 
   // Generate private setters for the builder to proxy into.
@@ -484,42 +523,49 @@ GenerateMembers(io::Printer* printer) const {
   }
 }
 
+
 void ImmutableMapFieldLiteGenerator::
 GenerateBuilderMembers(io::Printer* printer) const {
   printer->Print(
       variables_,
+      "@java.lang.Override\n"
       "$deprecation$\n"
-      "public int get$capitalized_name$Count() {\n"
+      "public int ${$get$capitalized_name$Count$}$() {\n"
       "  return instance.get$capitalized_name$Map().size();\n"
       "}\n");
+  printer->Annotate("{", "}", descriptor_);
   WriteFieldDocComment(printer, descriptor_);
   printer->Print(
       variables_,
+      "@java.lang.Override\n"
       "$deprecation$\n"
-      "public boolean contains$capitalized_name$(\n"
+      "public boolean ${$contains$capitalized_name$$}$(\n"
       "    $key_type$ key) {\n"
       "  $key_null_check$\n"
       "  return instance.get$capitalized_name$Map().containsKey(key);\n"
       "}\n");
+  printer->Annotate("{", "}", descriptor_);
   printer->Print(
       variables_,
       "$deprecation$\n"
-      "public Builder clear$capitalized_name$() {\n"
+      "public Builder ${$clear$capitalized_name$$}$() {\n"
       "  copyOnWrite();\n"
       "  instance.getMutable$capitalized_name$Map().clear();\n"
       "  return this;\n"
       "}\n");
+  printer->Annotate("{", "}", descriptor_);
   WriteFieldDocComment(printer, descriptor_);
   printer->Print(
       variables_,
       "$deprecation$\n"
-      "public Builder remove$capitalized_name$(\n"
+      "public Builder ${$remove$capitalized_name$$}$(\n"
       "    $key_type$ key) {\n"
       "  $key_null_check$\n"
       "  copyOnWrite();\n"
       "  instance.getMutable$capitalized_name$Map().remove(key);\n"
       "  return this;\n"
       "}\n");
+  printer->Annotate("{", "}", descriptor_);
   if (GetJavaType(ValueField(descriptor_)) == JAVATYPE_ENUM) {
     printer->Print(
         variables_,
@@ -528,23 +574,27 @@ GenerateBuilderMembers(io::Printer* printer) const {
         " */\n"
         "@java.lang.Deprecated\n"
         "public java.util.Map<$boxed_key_type$, $value_enum_type$>\n"
-        "get$capitalized_name$() {\n"
+        "${$get$capitalized_name$$}$() {\n"
         "  return get$capitalized_name$Map();\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
         "public java.util.Map<$boxed_key_type$, $value_enum_type$>\n"
-        "get$capitalized_name$Map() {\n"
+        "${$get$capitalized_name$Map$}$() {\n"
         "  return java.util.Collections.unmodifiableMap(\n"
         "      instance.get$capitalized_name$Map());\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_enum_type$ get$capitalized_name$OrDefault(\n"
+        "public $value_enum_type$ ${$get$capitalized_name$OrDefault$}$(\n"
         "    $key_type$ key,\n"
         "    $value_enum_type$ defaultValue) {\n"
         "  $key_null_check$\n"
@@ -554,11 +604,13 @@ GenerateBuilderMembers(io::Printer* printer) const {
         "         ? map.get(key)\n"
         "         : defaultValue;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_enum_type$ get$capitalized_name$OrThrow(\n"
+        "public $value_enum_type$ ${$get$capitalized_name$OrThrow$}$(\n"
         "    $key_type$ key) {\n"
         "  $key_null_check$\n"
         "  java.util.Map<$boxed_key_type$, $value_enum_type$> map =\n"
@@ -568,10 +620,11 @@ GenerateBuilderMembers(io::Printer* printer) const {
         "  }\n"
         "  return map.get(key);\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
-        "$deprecation$public Builder put$capitalized_name$(\n"
+        "$deprecation$public Builder ${$put$capitalized_name$$}$(\n"
         "    $key_type$ key,\n"
         "    $value_enum_type$ value) {\n"
         "  $key_null_check$\n"
@@ -580,40 +633,47 @@ GenerateBuilderMembers(io::Printer* printer) const {
         "  instance.getMutable$capitalized_name$Map().put(key, value);\n"
         "  return this;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
-        "$deprecation$public Builder putAll$capitalized_name$(\n"
+        "$deprecation$public Builder ${$putAll$capitalized_name$$}$(\n"
         "    java.util.Map<$boxed_key_type$, $value_enum_type$> values) {\n"
         "  copyOnWrite();\n"
         "  instance.getMutable$capitalized_name$Map().putAll(values);\n"
         "  return this;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     if (SupportUnknownEnumValue(descriptor_->file())) {
       printer->Print(
           variables_,
           "/**\n"
           " * Use {@link #get$capitalized_name$ValueMap()} instead.\n"
           " */\n"
+          "@java.lang.Override\n"
           "@java.lang.Deprecated\n"
           "public java.util.Map<$boxed_key_type$, $boxed_value_type$>\n"
-          "get$capitalized_name$Value() {\n"
+          "${$get$capitalized_name$Value$}$() {\n"
           "  return get$capitalized_name$ValueMap();\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
+          "@java.lang.Override\n"
           "$deprecation$\n"
           "public java.util.Map<$boxed_key_type$, $boxed_value_type$>\n"
-          "get$capitalized_name$ValueMap() {\n"
+          "${$get$capitalized_name$ValueMap$}$() {\n"
           "  return java.util.Collections.unmodifiableMap(\n"
           "      instance.get$capitalized_name$ValueMap());\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
+          "@java.lang.Override\n"
           "$deprecation$\n"
-          "public $value_type$ get$capitalized_name$ValueOrDefault(\n"
+          "public $value_type$ ${$get$capitalized_name$ValueOrDefault$}$(\n"
           "    $key_type$ key,\n"
           "    $value_type$ defaultValue) {\n"
           "  $key_null_check$\n"
@@ -621,11 +681,13 @@ GenerateBuilderMembers(io::Printer* printer) const {
           "      instance.get$capitalized_name$ValueMap();\n"
           "  return map.containsKey(key) ? map.get(key) : defaultValue;\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
+          "@java.lang.Override\n"
           "$deprecation$\n"
-          "public $value_type$ get$capitalized_name$ValueOrThrow(\n"
+          "public $value_type$ ${$get$capitalized_name$ValueOrThrow$}$(\n"
           "    $key_type$ key) {\n"
           "  $key_null_check$\n"
           "  java.util.Map<$boxed_key_type$, $boxed_value_type$> map =\n"
@@ -635,29 +697,29 @@ GenerateBuilderMembers(io::Printer* printer) const {
           "  }\n"
           "  return map.get(key);\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
-          "$deprecation$public Builder put$capitalized_name$Value(\n"
+          "$deprecation$public Builder ${$put$capitalized_name$Value$}$(\n"
           "    $key_type$ key,\n"
           "    $value_type$ value) {\n"
           "  $key_null_check$\n"
-          "  if ($value_enum_type$.forNumber(value) == null) {\n"
-          "    throw new java.lang.IllegalArgumentException();\n"
-          "  }\n"
           "  copyOnWrite();\n"
           "  instance.getMutable$capitalized_name$ValueMap().put(key, value);\n"
           "  return this;\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
       WriteFieldDocComment(printer, descriptor_);
       printer->Print(
           variables_,
-          "$deprecation$public Builder putAll$capitalized_name$Value(\n"
+          "$deprecation$public Builder ${$putAll$capitalized_name$Value$}$(\n"
           "    java.util.Map<$boxed_key_type$, $boxed_value_type$> values) {\n"
           "  copyOnWrite();\n"
           "  instance.getMutable$capitalized_name$ValueMap().putAll(values);\n"
           "  return this;\n"
           "}\n");
+      printer->Annotate("{", "}", descriptor_);
     }
   } else {
     printer->Print(
@@ -665,23 +727,30 @@ GenerateBuilderMembers(io::Printer* printer) const {
         "/**\n"
         " * Use {@link #get$capitalized_name$Map()} instead.\n"
         " */\n"
+        "@java.lang.Override\n"
         "@java.lang.Deprecated\n"
-        "public java.util.Map<$type_parameters$> get$capitalized_name$() {\n"
+        "public java.util.Map<$type_parameters$> "
+        "${$get$capitalized_name$$}$() {\n"
         "  return get$capitalized_name$Map();\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$"
-        "public java.util.Map<$type_parameters$> get$capitalized_name$Map() {\n"
+        "public java.util.Map<$type_parameters$> "
+        "${$get$capitalized_name$Map$}$() {\n"
         "  return java.util.Collections.unmodifiableMap(\n"
         "      instance.get$capitalized_name$Map());\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_type$ get$capitalized_name$OrDefault(\n"
+        "public $value_type$ ${$get$capitalized_name$OrDefault$}$(\n"
         "    $key_type$ key,\n"
         "    $value_type$ defaultValue) {\n"
         "  $key_null_check$\n"
@@ -689,11 +758,13 @@ GenerateBuilderMembers(io::Printer* printer) const {
         "      instance.get$capitalized_name$Map();\n"
         "  return map.containsKey(key) ? map.get(key) : defaultValue;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
+        "@java.lang.Override\n"
         "$deprecation$\n"
-        "public $value_type$ get$capitalized_name$OrThrow(\n"
+        "public $value_type$ ${$get$capitalized_name$OrThrow$}$(\n"
         "    $key_type$ key) {\n"
         "  $key_null_check$\n"
         "  java.util.Map<$type_parameters$> map =\n"
@@ -703,11 +774,12 @@ GenerateBuilderMembers(io::Printer* printer) const {
         "  }\n"
         "  return map.get(key);\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
         "$deprecation$"
-        "public Builder put$capitalized_name$(\n"
+        "public Builder ${$put$capitalized_name$$}$(\n"
         "    $key_type$ key,\n"
         "    $value_type$ value) {\n"
         "  $key_null_check$\n"
@@ -716,16 +788,18 @@ GenerateBuilderMembers(io::Printer* printer) const {
         "  instance.getMutable$capitalized_name$Map().put(key, value);\n"
         "  return this;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
     WriteFieldDocComment(printer, descriptor_);
     printer->Print(
         variables_,
         "$deprecation$"
-        "public Builder putAll$capitalized_name$(\n"
+        "public Builder ${$putAll$capitalized_name$$}$(\n"
         "    java.util.Map<$type_parameters$> values) {\n"
         "  copyOnWrite();\n"
         "  instance.getMutable$capitalized_name$Map().putAll(values);\n"
         "  return this;\n"
         "}\n");
+    printer->Annotate("{", "}", descriptor_);
   }
 }
 
